django-andablog
===============

|Build Status|

(Just) A blog app for Django
~~~~~~~~~~~~~~~~~~~~~~~~~~~~

What is the point of all this? When this project got started blogging
apps for Django generally fell into one of these categories:

1. A full CMS framework.
2. A Django App but intended for blog-only sites.
3. A Django App but intended for either a blog-only site (the default)
   or a site with a blog attached.

Though all three of these categories had great projects to choose from
any one of them could be frustrating to implement into (and maintain
within) an existing site. Simply because the app was not directly and
exclusively focused on the use case of a django site, and a blog (get
it?).

Andablog has a focus on integration-ease first and features second. So
if the focus of your Django site is something else and you want to add a
blog section to it you have come to the right place.

Full
`documentation <http://django-andablog.readthedocs.org/en/latest/>`__ is
available but here are the highlights.

-  `Features <http://django-andablog.readthedocs.org/en/latest/#features>`__
-  `Installation &
   Usage <http://django-andablog.readthedocs.org/en/latest/install-usage.html>`__
-  `Demo
   Site <http://django-andablog.readthedocs.org/en/latest/demo-site.html>`__

.. |Build Status| image:: https://travis-ci.org/WimpyAnalytics/django-andablog.svg?branch=master
   :target: https://travis-ci.org/WimpyAnalytics/django-andablog
